#### Admin-Setup ##############################
# - Passwort fuer Admin-Account setzen
# - LUKS-Passwort hinzufuegen
#
# Aufruf:    admin_setup
# Variablen: INSTALL_USER=homa
###############################################

## Passwort fuer Admin-Nutzer (Install-Nutzer) neu setzen
# Input:    INSTALL_USER
# Output:   NEWPASS
change_admin_pw () {
    if ! getent passwd "$INSTALL_USER" > /dev/null 2>&1 ; then
        zenity --error --width=500 \
           --text="Fehler: den Nutzer '<tt>$INSTALL_USER</tt>' gibt es nicht.\n\nBitte die Konfigurationsdateien korrigieren."
        exit 1
    fi
    ask_pass "$INSTALL_USER" \
    && echo "$INSTALL_USER:$NEWPASS" | chpasswd
}

## Admin-Nutzer-Passwort zu LUKS hinzufuegen
# Input:    NEWPASS
# Optional: CRYPT_DEFAULT_PW  CRYPT_DEV
luks_add_pw () {
    oldpassfile="$(mktemp)" \
    && echo -n "$CRYPT_DEFAULT_PW" > "$oldpassfile" \
    && echo "$NEWPASS" | cryptsetup luksAddKey $CRYPT_DEV --key-file="$oldpassfile" \
        | wait_for_luks \
    && rm -v "$oldpassfile"
}

## Admin-Passwort zentral ablegen
# Input:    NEWPASS
# FIXME noch nicht vorhanden
upload_admin_pwhash () {
    info_msg_timeout "Passwort-Upload noch nicht vorhanden" "Passwort-Upload ist noch nicht implementiert." "Passwort manuell in 'pass' eintragen!"
}

## Admin-Nutzer Einrichtung
admin_setup () {
    check_done "admin_setup" && return 0
    change_admin_pw \
    && luks_add_pw \
    && upload_admin_pwhash \
    && mark_done "admin_setup"
}

#### Admin-Setup - Ende #######################
