############################################################################
# GRUB-Setup
# - Passwortabfrage in Grub aktivieren
# - Das Passwort NEWPASS (von apcadmin) hinterlegen
# - Das Paket luh-pwless-grub-config installieren, damit normale
#   Linux-Menue-Punkte ohne Passwort nutzbar sind.
#
# Aufruf:    grub_setup
# Variablen: NEWPASS
############################################################################

GRUB_HEADER_FILE="/etc/grub.d/01_password-protect"
GRUB_CONFIG_LINUX="/etc/grub.d/10_linux"

## Passwort-Schutz in GRUB aktivieren
# - superusers-Variable setzen (mit dem Eintrag apcadmin)
# - Diese Variable exportieren, damit sie auch in Untermenues gilt
# - Das Passwort NEWPASS (von apcadmin) hinzufuegen
# Input: NEWPASS
add_grub_password () {
	PWHASH="$( echo -e "$NEWPASS\n$NEWPASS\n" \
		| grub-mkpasswd-pbkdf2 \
		| grep 'grub\.pbkdf2\.' \
		| sed  's/.* \(grub\.pbkdf2\..*\)/\1/' \
		)"
	cat > "$GRUB_HEADER_FILE" <<-EOF
		echo "set superusers=\"apcadmin\""
		echo "export superusers"
		echo "password_pbkdf2 apcadmin $PWHASH"
	EOF
	chmod u+x,go= "$GRUB_HEADER_FILE"
}

## GRUB-Einrichtung
# Input: NEWPASS
grub_setup () {
    # FIXME: 'mkdir && touch /var/lib/luh-pwless-grub-config/unpatch_grub_done' is only needed
    #  as long as luh-pwless-grub-config tries to undo the patching done previously here.
    check_done "grub_setup" && return 0
	add_grub_password \
    && mkdir -p /var/lib/luh-pwless-grub-config \
    && touch /var/lib/luh-pwless-grub-config/unpatch_grub_done \
    && install_pkg luh-pwless-grub-config \
    && mark_done "grub_setup"
}
