#!/bin/bash

#### Hilfs-Funktionen #########################

# Fehler und Info-Fenster
error_msg () { zenity --error --no-markup --width=500 --title="HOMA: Fehler: $1" --text="$(echo -e "$2\n\n${3:-}")" ; }
info_msg () {  zenity --info --width=500 --title="HOMA: Info: $1" --text="$(echo -e "$2\n\n${3:-}")" ; }
info_msg_timeout () {
    # timeout returns $?=5
    zenity --info --timeout 6 --width=500 --title="HOMA: Info: $1" --text="$(echo -e "$2\n\n${3:-}")" \
    || true
}
wait_for_progress () {
    zenity --progress --pulsate --no-cancel --auto-close \
        --width=400 \
        --title="HOMA: Bitte warten" \
        ${1:+--text="$1"}
}
wait_for_luks () { wait_for_progress "LUKS-Passwort wird geändert..."; }

# Eine Aufgabe als erledigt markieren, bzw. Status pruefen
STATE_FILE="/var/lib/luh-homa-setup/state"
mkdir -p "$(dirname "$STATE_FILE")"
touch "$STATE_FILE"

mark_done () {
    echo "$1" >> "$STATE_FILE"
}
check_done () {
    set +e
    grep -q "$1" "$STATE_FILE" 2>/dev/null
    RET="$?"
    set -e
    return "$RET"
}

# Neues Passwort abfragen (und mit cracklib testen)
# Eingabe:  $1=Username
# Export:   NEWPASS
ask_pass () {
    THISUSER="$1"
    PW_OK=false
    CHECKPW_RESULT=''
    while ! $PW_OK ; do
        while ! $PW_OK ; do
            NEWPASS=$(zenity \
                    --entry --hide-text --width=500 \
                    --title="Passwort festlegen ($THISUSER)" \
                    --text="${CHECKPW_RESULT}Neues Passwort für $THISUSER:" ) \
                || return 3
            CHECKPW="$(export LANG=de_DE.UTF-8; echo "$NEWPASS" | cracklib-check )"
            CHECKPW_RESULT="${CHECKPW##*: }"
            [ "${CHECKPW_RESULT}" = "OK" ] && PW_OK=true \
                || CHECKPW_RESULT="Passwort-Test fehlgeschlagen: $CHECKPW_RESULT\n\n"
        done

        NEWPASS2=$(zenity  \
            --entry --hide-text --width=500 \
            --title="Passwort festlegen ($THISUSER)" \
            --text='Passwort wiederholen:' ) \
            || return 4
        if [ "$NEWPASS" != "$NEWPASS2" ] ; then
            PW_OK=false
            CHECKPW_RESULT="Passwort-Test fehlgeschlagen: Die Passwörter sind nicht identisch.\n\n"
        fi
    done
    export NEWPASS
}


export DEBIAN_FRONTEND=noninteractive
APT_OPTS="-o Dpkg::Options::=--force-confdef -o Dpkg::Options::=--force-confnew -o DPkg::Lock::Timeout=-1"

# apt update; apt upgrade
apt_upgrade () {
    # To avoid doing the upgrade more than once, we use a mark.
    check_done "apt_upgrade" && return 0
    apt update \
        | wait_for_progress "Aktualisiere Paketlisten..."
    apt --yes $APT_OPTS upgrade \
        | wait_for_progress "Installiere Updates..."
    mark_done "apt_upgrade"
}

## Pakete via apt installieren
# Variablen:  $@ = Paketliste
install_pkg () {
    apt_upgrade
    apt --yes $APT_OPTS install "$@" \
        | wait_for_progress "Installiere $* ..."
}

#### Hilfs-Funktionen - Ende ##################
