#!/bin/bash

#### Nutzereinrichtung #####################################
# Aufruf: user_setup

# Abfrage: Neuen Nutzer anlegen?
ask_create_user () {
    zenity    --question \
        --width=500 \
        --title='neuen Nutzer einrichten?' \
        --text='Soll ein neuer Nutzer eingerichtet werden?'
}

# Nutzerdaten abfragen und pruefen
# NEWGECOS NEWUSER
ask_user_data () {
    NEWGECOS=$(zenity  --entry --width=500 --title='Nutzerinformationen eingeben' \
        --text='Vor- und Nachname des Nutzers (GECOS)' ) \
        && [ -n "$NEWGECOS" ] \
        || return 1
    NEWLASTNAME="${NEWGECOS##* }"
    NEWUSER="${NEWUSER:-${NEWLASTNAME,,}}"
    NEWUSER="$(echo "$NEWUSER"| sed -e 's/ä/ae/g;s/ö/oe/g;s/ü/ue/g')"
    NEWUSER=$(zenity  --entry --width=500 --title='Nutzerinformationen eingeben' \
        --text='Username (wie in der Domäne; klein und zusammengeschrieben)' \
        --entry-text="$NEWUSER" ) \
        && [ -n "$NEWGECOS" ] \
        || return 2
    export NEWGECOS NEWUSER
}

# Neuen Nutzer anlegen und Verschluessellungs-Passwort setzen
# Input:    CRYPT_DEV  CRYPT_DEFAULT_PW
#           USER_GROUPS
create_user () {
    getent passwd "$NEWUSER" > /dev/null 2>&1 \
        && zenity --error --width=500 \
        --text="Fehler: den Nutzer '<tt>$NEWUSER</tt>' gibt es schon.\n\nEr kann daher nicht neu angelegt werden." \
        && return 1

    useradd "$NEWUSER" -m -c "$NEWGECOS,,," -G "$USER_GROUPS" -s /bin/bash \
    && echo "$NEWUSER:$NEWPASS" | chpasswd \
    \
    && oldpassfile="$(mktemp)" \
    && echo -n "$CRYPT_DEFAULT_PW" > "$oldpassfile" \
    && echo "$NEWPASS" | cryptsetup luksChangeKey $CRYPT_DEV --key-file="$oldpassfile" \
        | wait_for_luks \
    && rm -v "$oldpassfile" \
    ||(  zenity --warning --width=500 --text='Es ist ein Fehler aufgetreten.' \
        && return 1)
}

# Nutzer-Einrichtungsmenue starten
user_setup () {
    while ask_create_user; do
        ask_user_data \
            && ask_pass "$NEWUSER" \
            && create_user \
            && mark_done user_setup \
            && break
    done
}

#### Nutzereinrichtung - Ende ##############################
